Hypermedia Client
=================

The Hypermedia client serves as a python developer's API for access to services
which return certain hypermedia mimetypes. The client self-discovers services 
from the endpoint and relies entirely upon responses from the server for 
operation. It can be considered a proxy for the REST service and allows 
developers to program against a hypermedia provider without need for 
understanding HTTP or network conceits aside from the root API URL. 

Currently support a subset of SIREN.
